@@ -2,7 +2,7 @@
 # LICENSE file is in the root directory of this source tree.
 import os
 import sys
-from ProjectGenerator import *
+from .ProjectGenerator import *
 import argparse
 
 __version__ = '0.0.1'
